@@ -9,12 +9,18 @@ class MultiValueBoundField(BoundField):
             template = "dynamic_forms/widgets/subfield_crispy.html"
         else:
             template = "dynamic_forms/widgets/subfield.html"
+        label = sub_bf.label_tag()
+        help_text = sub_bf.field.help_text
+        if sub_bf.field_type == 'HTMLField':
+            label = ''
+            help_text = ''
+
         return render_to_string(
             template,
             context={
-                'label': sub_bf.label_tag(),
+                'label': label,
                 'field': sub_bf,
-                'help_text': sub_bf.field.help_text
+                'help_text': help_text
             }
         )
 
@@ -22,6 +28,7 @@ class MultiValueBoundField(BoundField):
         subfield_widgets = []
         for i, subfield in enumerate(self.field.fields):
             sub_bf = BoundField(self.form, subfield, "{}_{}".format(self.name, i))
+            sub_bf.field_type = subfield.__class__.__name__
             subfield_widgets.append(self._subfield_as_widget(sub_bf))
         return render_to_string(
             "dynamic_forms/widgets/formrender.html",
